%% FLUORESCENCE2D:  DISPLAY OF 2D FLUORESCENCE SPECTRA
% Evgenii L. Kovrigin, Marquette University
% ver. 3.0    6/25/2013-5/6/2014
%
% This program displays 2D fluorescence spectra and their
% vertical and horizontal slices. The data are prepared
% by a converter such as "pti2fluorescence2D.py".
%
% Bugs and fixes:
% 3/8/2014 - Baseline subtraction introduced
% 5/6/2014 - Version 3 (in response to PLoS One reviews)
% 
%%
close all
clear all

%% DATA SOURCE

% % Buffer solution
%  settings.dname='buffer.txt.corr';
%  settings.lowest_contour_percent=0;  % percentile of data at which to draw the lowest contour 
%  settings.highest_contour_percent=10;  % percentile of data at which to draw the highest contour 

% % Tyrosine-mant sample
 settings.dname='Tyrosine_mant.txt.corr';
 settings.lowest_contour_percent=3;  % percentile of data at which to draw the lowest contour 
 settings.highest_contour_percent=13;  % percentile of data at which to draw the highest contour 

% Baseline data or any spectrum to subtract
settings.baseline_name='buffer.txt.corr';
settings.baseline_correction='yes'; % Subtract this dataset as baseline?  'yes'/'no'

%% OPERATION MODE
% Uncomment necessary mode
settings.mode='2D';   % Use to plot 2D spectrum as a color map
%  settings.mode='1D emission slice'; % Use to extract 1D emission slice
%  settings.mode='1D excitation slice';  % Use to extract 1D excitation slice


%% COMMON PARAMETERS
settings.graphics_export='on'; % 'on' --- saving the figures  'off' -- only show them on screen

% Formats and resolution of the figures to be saved:
settings.export_fine_png='yes';  % 'yes'to turn on export
settings.resolution_fine_png  = 300 ; % dots-per-inch; larger number makes larger file. 
settings.export_small_png='yes';  % 'yes'to turn on export
settings.resolution_small_png = 65 ; % dots-per-inch; larger number makes larger file
settings.export_eps='yes';  % 'yes'to turn on export


%% 2D PARAMETERS
settings.colormap_name='Jet';  % Color scheme (see MATLAB help for 'colormap')
settings.N_colors=100 ; %  number of colors in the color map


%% 1D EMISSION SLICE PARAMETERS
settings.emission_spectrum_excited_at=360;  % nm value of the excitation wavelength for the emission slice
settings.emission_spectrum_X_min=370;
settings.emission_spectrum_X_max=700;

%% 1D EXCITATION SLICE PARAMETERS
settings.excitation_spectrum_detected_at=440; % nm value of the detection wavelength for the excitation slice
settings.excitation_spectrum_X_min=250;
settings.excitation_spectrum_X_max=430;






%%% =============== END OF USER INPUT SECTION ===========================






%% Load 
data.X=load(fullfile(settings.dname,'emission_wavelengths_Xaxis.txt'));
data.Y=load(fullfile(settings.dname,'excitation_wavelengths_Yaxis.txt'));
data.Z=load(fullfile(settings.dname,'spectral_intensity.txt'));

switch settings.baseline_correction
    case 'yes'
        fprintf(1,'Calculating baseline corrected spectra\n');
        
        baseline_data.X=load(fullfile(settings.baseline_name,'emission_wavelengths_Xaxis.txt'));
        baseline_data.Y=load(fullfile(settings.baseline_name,'excitation_wavelengths_Yaxis.txt'));
        baseline_data.Z=load(fullfile(settings.baseline_name,'spectral_intensity.txt'));
        
        % are the sizes the same?
        if length(data.X)~=length(baseline_data.X)
            error('\n\nERROR!\nThe baseline data \"%s\" have number of X axis values than \"%s\"!\n\n', ...
                settings.baseline_name, settings.dname);
        end
        if length(data.Y)~=length(baseline_data.Y)
            error('\n\nERROR!\nThe baseline data \"%s\" have number of Y axis values than \"%s\"!\n\n', ...
                settings.baseline_name, settings.dname);
        end
        
        % Check if the baseline dataset is point-by-point matching the data
        if sum(data.X-baseline_data.X)~=0 
        end
        if  sum(data.Y-baseline_data.Y)~=0 
            error('\n\nERROR!\nThe baseline data \"%s\" have different Y axis values than \"%s\"!\n\n', ...
                settings.baseline_name, settings.dname);
        end
        % All clear, sizes and values are the same. Subtract baseline.
        new_data=data.Z-baseline_data.Z;
        data.Z=new_data;
        % save corrected 2D data
        fname_corrected=fullfile(settings.dname,'spectral_intensity_baseline_corrected.txt');
        save(fname_corrected, 'new_data','-ascii');
        
    otherwise
        fprintf(1,'Baseline correction is not performed\n');
end

%% Call the appropriate module
switch settings.mode
    case '1D emission slice'
        fluorescence2Dslice1D(data, settings)  % this module switches between emission and excitation itself
    case '1D excitation slice'
        fluorescence2Dslice1D(data, settings)  % this module switches between emission and excitation itself
    case '2D'
        fluorescence2Dplot(data, settings)
    otherwise
        error('\nUnknown plotting mode: %s!\n\n', settings.mode)
end


